@@ -1,6 +1,9 @@
 from time import sleep
 
 import dpp_common_utils.selenium
+from requests.exceptions import InvalidURL
+from selenium.common.exceptions import WebDriverException
+
 from html_processing.parser import get_html_parser
 from lxml import etree
 from lxml.html import HtmlElement
@@ -17,7 +20,10 @@ def lxml_connect(url):
 
     parser = get_html_parser()
     driver = dpp_common_utils.selenium.get_driver(True)
-    driver.get(url)
+    try:
+        driver.get(url)
+    except WebDriverException:
+        return InvalidURL
     sleep(5)  # sleep - the script has to be loaded and this needs time
     res = driver.page_source
 
